# augment.preprocess

## RemoveType

::: fastaudio.augment.preprocess.RemoveType
    :docstring:
    :members:

## RemoveSilence

::: fastaudio.augment.preprocess.RemoveSilence
    :docstring:

## Resample

::: fastaudio.augment.preprocess.Resample
    :docstring:
